type Lines = Array<string> | string;
export interface Link {
    url: string;
    inner: string;
    title?: string;
}
/** Escape characters that can interfere with HTML and Markdown attributes */
export declare function escapeAttribute(str: string): string;
/** Combine lines that aren't empty */
export declare function lines(items: Lines): string;
/** Join all lines */
export declare function join(items: Lines, join?: string): string;
/** Trim whitespace from the start and end */
export declare function trim(str: string): string;
/** Wrap the item */
export declare function wrap(prefix: string | undefined, suffix: string | undefined, item: string): string;
/** WRap each item */
export declare function wrapEach(prefix: string | undefined, suffix: string | undefined, items: Lines): Array<string>;
/** Wrap the item in a tag */
export declare function tag(name: string | undefined, item: string): string;
/** Wrap each item in a tag */
export declare function tagEach(name: string | undefined, items: Lines): Array<string>;
/** Render items conditionally */
export declare function i(condition: any, items: () => Lines): string;
/** Render text */
export declare function t(items: Lines): string;
/** Render line break */
export declare function br(): string;
/** Render HTML paragraph */
export declare function p(items: Lines): string;
/** Render Markdown paragraph */
export declare function mp(items: Lines): string;
/** Render HTML heading */
export declare function h(level: number, item: string): string;
/** Render Markdown heading */
export declare function mh(level: number, item: string): string;
/** Render HTML h1 */
export declare function h1(item: string): string;
/** Render Markdown h1 */
export declare function mh1(item: string): string;
/** Render HTML h2 */
export declare function h2(item: string): string;
/** Render Markdown h2 */
export declare function mh2(item: string): string;
/** Render HTML h3 */
export declare function h3(item: string): string;
/** Render Markdown h3 */
export declare function mh3(item: string): string;
/** Render HTML h4 */
export declare function h4(item: string): string;
/** Render Markdown h4 */
export declare function mh4(item: string): string;
/** Render HTML h5 */
export declare function h5(item: string): string;
/** Render Markdown h5 */
export declare function mh5(item: string): string;
/** Render HTML h6 */
export declare function h6(item: string): string;
/** Render Markdown h6 */
export declare function mh6(item: string): string;
/** Render HTML strong */
export declare function strong(item: string): string;
/** Render Markdown strong */
export declare function mstrong(item: string): string;
/** Render HTML em */
export declare function em(item: string): string;
/** Render Markdown em */
export declare function mem(item: string): string;
/** Render HTML blockquote */
export declare function blockquote(items: Lines): string;
/** Render Markdown blockquote */
export declare function mblockquote(items: Lines): string;
/** Render HTML pre */
export declare function pre(items: Lines): string;
/** Render HTML inline code */
export declare function code(item: string): string;
/** Render Markdown inline code */
export declare function mcode(item: string): string;
/** Render Markdown code block */
export declare function mcodeblock(format: string, items: Lines): string;
/** Render HTML list element */
export declare function li(items: Array<string>): string;
/** Render HTML unordered list */
export declare function ul(items: Array<string>): string;
/** Render Markdown unordered list */
export declare function mul(items: Array<string>): string;
/** Render HTML ordered list */
export declare function ol(items: Array<string>): string;
/** Render Markdown ordered list */
export declare function mol(items: Array<string>): string;
/** Render HTML link */
export declare function a({ url, inner, title }: Link): string;
/** Render Markdown link */
export declare function ma({ url, inner, title }: Link): string;
export {};
//# sourceMappingURL=index.d.ts.map